@@ -14,6 +14,7 @@
 #    under the License.
 
 import logging
+import re
 
 import webob.dec
 import webob.exc
@@ -24,8 +25,10 @@ from oslo_middleware import base
 
 LOG = logging.getLogger(__name__)
 
+_TOKEN_RE = re.compile('^(X-\w+-Token):.*$', flags=re.MULTILINE)
 
-class CatchErrors(base.Middleware):
+
+class CatchErrors(base.ConfigurableMiddleware):
     """Middleware that provides high-level error handling.
 
     It catches all exceptions from subsequent applications in WSGI pipeline
@@ -37,7 +40,8 @@ class CatchErrors(base.Middleware):
         try:
             response = req.get_response(self.application)
         except Exception:
+            req_str = _TOKEN_RE.sub(r'\1: *****', req.as_text())
             LOG.exception(_LE('An error occurred during '
-                              'processing the request: %s'))
+                              'processing the request: %s'), req_str)
             response = webob.exc.HTTPInternalServerError()
         return response
