@@ -14,22 +14,36 @@
 #    under the License.
 
 import abc
-import collections
 
 import six
 
-HealthcheckResult = collections.namedtuple(
-    'HealthcheckResult', ['available', 'reason'], verbose=True)
+
+class HealthcheckResult(object):
+    """Result of a ``healthcheck`` method call should be this object."""
+
+    def __init__(self, available, reason, details=None):
+        self.available = available
+        self.reason = reason
+        self.details = details
 
 
 @six.add_metaclass(abc.ABCMeta)
 class HealthcheckBaseExtension(object):
-    def __init__(self, conf):
+
+    def __init__(self, oslo_conf, conf):
+        self.oslo_conf = oslo_conf
         self.conf = conf
 
     @abc.abstractmethod
-    def healthcheck():
+    def healthcheck(self, server_port):
         """method called by the healthcheck middleware
 
         return: HealthcheckResult object
         """
+
+    def _conf_get(self, key, group='healthcheck'):
+        if key in self.conf:
+            # Validate value type
+            self.oslo_conf.set_override(key, self.conf[key], group=group,
+                                        enforce_type=True)
+        return getattr(getattr(self.oslo_conf, group), key)
